const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# um cardinal para o cabeçalho principal",
    "## two hashes for second heading": "## dois cardinais para o segundo cabeçalho",
    "### three hashes for third heading": "### três cardinais para o terceiro cabeçalho",
    "**double star for bold**": "**dois asteriscos para negrito**",
    "*single star for italic*": "**um asterisco para itálico*",
    "--- for a horizontal rule": "--- para uma régua horizontal",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Lista de números separada por vírgulas que define o padrão do traço. Por exemplo \"5, 10, 15\".",
    "About": "Sobre",
    "Action not allowed :(": "Ação não permitida :(",
    "Activate slideshow mode": "Ativar modo de apresentação",
    "Add a layer": "Adicionar camada",
    "Add a line to the current multi": "Adicionar uma linha para o multi atual",
    "Add a polygon to the current multi": "Adicionar um polígono para o multi atual",
    "Add image URL": "Adicionar URL da imagem",
    "Advanced actions": "Ações avançadas",
    "Advanced properties": "Propriedades avançadas",
    "All data and settings of the map": "Todos os dados e definições do mapa",
    "All properties are imported.": "Foram importadas todas as propriedades.",
    "Allow interactions": "Permitir interações",
    "Allow scroll wheel zoom?": "Permitir zoom com roda do rato?",
    "always": "sempre",
    "Animated transitions": "Transições animadas",
    "Are you sure you want to clone this map and all its datalayers?": "Tem a certeza que quer clonar este mapa, incluindo todas as camadas de dados?",
    "Are you sure you want to delete this map?": "Tem a certeza que quer eliminar este mapa?",
    "Are you sure you want to restore this version?": "Tem a certeza que quer restaurar esta versão?",
    "Attach the map to my account": "Anexar o mapa à minha conta",
    "attribution": "atribuição",
    "Auto": "Auto",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Iniciar ao abrir o mapa",
    "Back to preview": "Voltar à pré-visualização",
    "Background overlay url": "URL da sobreposição de fundo",
    "Ball": "Bola",
    "Bring feature to center": "Colocar o elemento no centro",
    "Browse data": "Explorar dados",
    "by": "por",
    "Cache proxied request": "Pedido cache com proxy",
    "Caption": "Cabeçalho",
    "Center map on your location": "Centrar mapa na sua localização",
    "Change tilelayers": "Alterar camadas de telas",
    "Change": "Alterar",
    "Choose the data format": "Escolha o formato dos dados",
    "Choropleth breakpoints": "Pontos de interrupção coropléticos",
    "Choropleth classes": "Classes coropléticas",
    "Choropleth color palette": "Palete de cores coropléticas",
    "Choropleth mode": "Modo coroplético",
    "Choropleth property value": "Valor da propriedade coroplética",
    "Choropleth": "Coroplético",
    "Circle": "Círculo",
    "clear": "limpar",
    "Click last point to finish shape": "Clique no último ponto para terminar a forma geométrica",
    "Click to add a marker": "Clique para adicionar um marcador",
    "Click to continue drawing": "Clique para continuar a desenhar",
    "Click to start drawing a line": "Clique para começar a desenhar uma linha",
    "Click to start drawing a polygon": "Clique para começar a desenhar um polígono",
    "Clone of {name}": "Clone de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Fechar",
    "Clustered": "Agregado",
    "Clustering radius": "Raio do aglomerado",
    "collapsed": "colapsado",
    "color": "cor",
    "Comma separated list of numbers, including min and max values.": "Lista de números separada por vírgulas, incluindo os valores mínimo e máximo.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Lista de propriedades separada por vírgulas a utilizar para ordenar as caraterísticas. Para inverter a ordenação, coloque um sinal de menos (-) antes. Por exemplo, minha chave,-outra chave.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the beginning of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the beginning of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Parabéns, o seu mapa foi criado!",
    "Continue line": "Continuar linha",
    "Coordinates": "Coordenadas",
    "copy": "copiar",
    "Credits": "Créditos",
    "Current map view": "Vista atual do mapa",
    "Current view instead of default map view?": "Vista atual e não a vista padrão do mapa?",
    "Custom background": "Fundo personalizado",
    "Custom overlay": "Sobreposição personalizada",
    "dash array": "série de traços",
    "Data is browsable": "Os dados são navegáveis",
    "Datalayers": "Camadas de dados",
    "Default interaction options": "Opções padrão de interação",
    "Default properties": "Propriedades padrão",
    "Default shape properties": "Propriedades padrão de formas geométricas",
    "Default view": "Vista padrão",
    "Default zoom level": "Nível de aproximação padrão",
    "Default": "Padrão",
    "Default: name": "Padrão: nome",
    "Define link to open in a new window on polygon click.": "Definir hiperligação para abrir numa nova janela ao clicar no polígono.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Atraso entre 2 transições ao reproduzir a apresentação",
    "Delete layer": "Eliminar camada",
    "Delete this feature": "Eliminar este elemento",
    "Delete this shape": "Eliminar esta forma geométrica",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+clique)",
    "Delete": "Eliminar",
    "description": "descrição",
    "Directions from here": "Direções a partir daqui",
    "Display label": "Mostrar etiqueta",
    "Display measure": "Mostrar medição",
    "display name": "mostrar nome",
    "Display on load": "Mostrar ao carregar",
    "Display the control to open OpenStreetMap editor": "Mostrar o controlo para abrir o editor OpenStreetMap",
    "Display the embed control": "Mostrar o controlo de embeber",
    "Display the fullscreen control": "Mostrar o controlo de ecrã total",
    "Display the locate control": "Mostrar o controlo de localizar",
    "Display the measure control": "Mostrar o controlo de medição",
    "Display the search control": "Mostrar o controlo de pesquisa",
    "Display the tile layers control": "Mostrar o controlo de camadas de telas",
    "Display the zoom control": "Mostrar o controlo de aproximar e afastar (zoom)",
    "Do you want to display a caption bar?": "Mostrar uma barra de cabeçalho?",
    "Do you want to display a minimap?": "Pretende mostrar um mini-mapa?",
    "Do you want to display a panel on load?": "Mostrar um painel ao carregar?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Pretende mostrar um popup no rodapé?",
    "Do you want to display the scale control?": "Pretende mostrar o controlo de escala?",
    "Do you want to display the «more» control?": "Mostrar o botão «mostrar mais botões»?",
    "Download": "Descarregar",
    "Drag to reorder": "Arrastar para reordenar",
    "Draw a marker": "Desenhar um marco",
    "Draw a polygon": "Desenhar um polígono",
    "Draw a polyline": "Desenhar uma polilinha",
    "Drawing": "Desenho",
    "Drop": "Comum",
    "Dynamic properties": "Propriedades dinâmicas",
    "Dynamic": "Dinâmico",
    "Edit feature's layer": "Editar camada do elemento",
    "Edit properties in a table": "Editar propriedades numa tabela",
    "Edit the title of the map": "Editar o título do mapa",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Opções de incorporação e hiperligação",
    "Emoji & Character": "Emoji e caracteres",
    "Empty": "Vazio",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Erro no URL da sobreposição",
    "Error in the tilelayer URL": "Erro no URL de telas",
    "Exit Fullscreen": "Sair do ecrã inteiro",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extrair forma geométrica para separar o elemento",
    "Feature identifier key": "Chave de identificação do elemento",
    "Feature properties": "Propriedades do elemento",
    "Fetch data each time map view changes.": "Processar dados cada vez que o mapa é alterado.",
    "fill color": "cor do preenchimento",
    "fill opacity": "opacidade do preenchimento",
    "fill": "preenchimento",
    "Fit all data": "Ajustar todos os dados",
    "Format": "Formato",
    "From zoom": "Do zoom",
    "full backup": "cópia de segurança completa",
    "GeoRSS (only link)": "GeoRSS (apenas a hiperligação)",
    "GeoRSS (title + image)": "GeoRSS (título + imagem)",
    "Go to \"{coords}\"": "Ir para \"{coords}\"",
    "Go to the homepage": "Ir para a página inicial",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap radius": "Raio do mapa térmico",
    "Heatmap": "Mapa térmico",
    "height": "altura",
    "Help": "Ajuda",
    "hidden": "oculto",
    "Hide controls": "Ocultar controlos",
    "Home": "Início",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Por quanto simplificar a polilinha em cada nível de aproximação (mais = melhor desempenho e aspeto mais suave, menos = mais preciso)",
    "icon opacity": "opacidade do ícone",
    "Icon shape": "Forma do ícone",
    "Icon symbol": "Símbolo do ícone",
    "If false, the polygon or line will act as a part of the underlying map.": "Se for falso, o polígono ou a linha atuará como parte do mapa subjacente.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Importar dados",
    "Import in a new layer": "Importar uma nova camada",
    "Imports all umap data, including layers and settings.": "Importa todos os dados uMap, incluindo camadas e definições.",
    "Include full screen link?": "Incluir a hiperligação para o ecrã completo?",
    "Inherit": "Herdado",
    "inherit": "herdado",
    "Interaction options": "Opções de interação",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Dados uMap inválidos em {filename}",
    "Invalid umap data": "Dados uMap inválidos",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Manter camadas atualmente visíveis",
    "kilometers": "quilómetros",
    "km": "km",
    "Label direction": "Direção da etiqueta",
    "Label key": "Chave da etiqueta",
    "Labels are clickable": "Etiquetas são clicáveis",
    "Latest feature": "Último elemento",
    "Latitude": "Latitude",
    "Layer properties": "Propriedades da camada",
    "Layer": "Camada",
    "Licence": "Licença",
    "licence": "licença",
    "Limit bounds": "Extremos dos limites",
    "Link to view the map": "Hiperligação para ver o mapa",
    "Link to…": "Hiperligação para…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Créditos por extenso",
    "Longitude": "Longitude",
    "Manage layers": "Gerir camadas",
    "Manual": "Manual",
    "Map background credits": "Créditos do fundo do mapa",
    "Map has been attached to your account": "O mapa foi anexado à sua conta",
    "Map has been saved!": "O mapa foi guardado!",
    "Map has been starred": "O mapa foi marcado como favorito",
    "Map has been unstarred": "O mapa foi desmarcado como favorito",
    "Map user content has been published under licence": "O conteúdo do mapa foi publicado sob a licença",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Proprietário do mapa",
    "max East": "Este máx.",
    "max North": "Norte máx.",
    "max South": "Sul máx.",
    "max West": "Oeste máx.",
    "max zoom": "aproximação máxima",
    "Measure distances": "Medir distâncias",
    "Merge lines": "Fundir linhas",
    "mi": "mi",
    "miles": "milhas",
    "min zoom": "aproximação mínima",
    "More controls": "Mais controlos",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Tem de ser um valor CSS válido (p.ex.: DarkBlue ou #123456)",
    "name": "nome",
    "nautical miles": "milhas náuticas",
    "never": "nunca",
    "new window": "nova janela",
    "next": "seguinte",
    "NM": "NM",
    "No cache": "Sem cache",
    "No licence has been set": "Não foi definida nenhuma licença",
    "No results": "Sem resultados",
    "no": "não",
    "No.": "No.",
    "None": "Nenhum",
    "Number of desired classes (default 5)": "Número de classes pretendidas (padrão: 5)",
    "On the bottom": "No fundo",
    "On the left": "Na esquerda",
    "On the right": "Na direita",
    "On the top": "No topo",
    "Only visible layers' data": "Apenas dados de camadas visíveis",
    "opacity": "opacidade",
    "Opacity": "Opacidade",
    "Open current feature on load": "Abrir o elemento atual ao carregar",
    "Open link in…": "Abrir hiperligação em…",
    "Open share & download panel": "Abrir painel de partilha e descarregamento",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abrir esta região do mapa num editor de mapas para fornecer dados mais precisos ao OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional. Same as color if not set.": "Opcional. Igual à cor se não for definido.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrepor raio do aglomerado (padrão: 80)",
    "Override heatmap radius (default 25)": "Sobrepor raio do mapa térmico (padrão: 25)",
    "parent window": "janela pai",
    "Paste your data here": "Cole aqui os seus dados",
    "Permalink": "Hiperligação permanente",
    "Permanent credits background": "Fundo dos créditos permanentes",
    "Permanent credits": "Créditos permanentes",
    "Please be sure the licence is compliant with your use.": "Confirme que a utilização está conforme a licença.",
    "Please choose a format": "Escolha um formato",
    "Please save the map first": "Guarde primeiro o mapa",
    "Popup (large)": "Popup (largo)",
    "Popup content style": "Estilo do conteúdo do popup",
    "Popup content template": "Modelo de conteúdo do popup",
    "Popup shape": "Forma do popup",
    "Popup": "Popup",
    "Powered by uMap": "Utilizado com uMap",
    "previous": "anterior",
    "Problem in the response": "Problema na resposta",
    "Properties imported:": "Propriedades importadas:",
    "Provide an URL here": "Forneça um URL aqui",
    "Proxy request": "Pedido proxy",
    "Quantiles": "Quantis",
    "Recent": "Recente",
    "Remote data": "Dados remotos",
    "Replace layer content": "Substituir o conteúdo da camada",
    "Restore this version": "Restaurar esta versão",
    "Save current edits": "Guardar edições atuais",
    "Save map": "Guardar mapa",
    "Save": "Guardar",
    "Saved center and zoom": "Guardar centro e aproximar",
    "Search location": "Procurar localização",
    "Search": "Procurar",
    "Secret edit link:": "Hiperligação secreta de edição:",
    "See full screen": "Ver ecrã inteiro",
    "See on OpenStreetMap": "Ver no OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Defina como falso para ocultar esta camada da apresentação de slides, o navegador de dados e da navegação do popup…",
    "settings": "definições",
    "Shape properties": "Propriedades de formas geométricas",
    "Share and download": "Partilhar e descarregar",
    "Short credits": "Créditos resumidos",
    "Short link": "Hiperligação curta",
    "Show this layer in the caption": "Mostrar esta camada na legenda",
    "Show/hide layer": "Mostrar / ocultar camada",
    "Side panel": "Painel lateral",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "A ignorar tipo de geometria desconhecido: {type}",
    "Slideshow": "Apresentação",
    "Sort key": "Chave de ordenação",
    "Split line": "Linha de separação",
    "Star this map": "Marcar o mapa como favorito",
    "Start a hole here": "Começar um buraco aqui",
    "Start slideshow": "Iniciar apresentação",
    "Stop editing": "Parar edição",
    "Stop slideshow": "Parar apresentação",
    "Street": "Rua",
    "stroke": "traço",
    "Supported scheme": "Esquema suportado",
    "Supported variables that will be dynamically replaced": "Variáveis suportadas que serão substituídas de forma dinâmica",
    "Symbol": "Símbolo",
    "Table": "Tabela",
    "Text color for the cluster label": "Cor do texto para a etiqueta do aglomerado",
    "Text formatting": "Formatação do texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "O nome da propriedade a utilizar como etiqueta do elemento (por exemplo: “nom”). Também pode utilizar propriedades entre parênteses para utilizar mais do que uma ou misturar com conteúdo estático (por exemplo: “&lcub;name&rcub; in &lcub;place&rcub;”)",
    "The name of the property to use as feature unique identifier.": "O nome da propriedade a utilizar como identificador único da caraterística.",
    "The zoom and center have been modified.": "O zoom e o centro foram alterados.",
    "TMS format": "Formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Para usar caso o servidor remoto não permitir domínios cruzados (mais lento)",
    "To zoom": "Ao zoom",
    "Toggle edit mode (⇧+Click)": "Alternar o modo de edição (⇧+clique)",
    "Toggle edit mode": "Alternar modo de edição",
    "Transfer shape to edited feature": "Transferir a forma geométrica para o elemento editado",
    "Transform to lines": "Transformar em linha",
    "Transform to polygon": "Transformar em polígono",
    "Type a place name or coordinates": "Introduzir um nome de local ou coordenadas",
    "Type char or paste emoji": "Introduzir um caractere ou colar um emoji",
    "Type of layer": "Tipo de camada",
    "Unable to detect format of file {filename}": "Não foi possível detetar o formato do ficheiro {filename}",
    "Untitled layer": "Camada sem nome",
    "Untitled map": "Mapa sem nome",
    "Update permissions and editors": "Alterar permisões e editores",
    "Update permissions": "Permissões de atualização",
    "Update who can see and edit the map": "Atualizar quem pode ver e editar o mapa",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Usar extremos atuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use espaços reservados como propriedades de elementos entre parêntesis. Por ex. &#123;nome&#125; e serão substituídos pelos valores correspondentes.",
    "User content credits": "Créditos do conteúdo do utilizador",
    "User interface options": "Opções da interface de utilizador",
    "User location": "Localização do utilizador",
    "Verify remote URL": "Verificar URL remoto",
    "Versions": "Versões",
    "View Fullscreen": "Ver ecrã inteiro",
    "View": "Ver",
    "Visibility: {status}": "Visibilidade: {status}",
    "weight": "espessura",
    "Where do we go from here?": "Para onde vamos a partir daqui?",
    "Whether to display or not polygons paths.": "Se mostrar ou não os caminhos dos polígonos.",
    "Whether to fill polygons with color.": "Se mostrar ou não os polígonos preenchidos a cor.",
    "Who can edit \"{layer}\"": "Quem pode editar \"{layer}\"",
    "Who can edit": "Quem pode editar",
    "Who can view": "Quem pode ver",
    "width": "largura",
    "Will be displayed in the bottom right corner of the map": "Será mostrado no fundo à direita do mapa",
    "Will be permanently visible in the bottom left corner of the map": "Estará permanentemente visível no canto inferior esquerdo do mapa",
    "Will be visible in the caption of the map": "Será visível no cabeçalho do mapa",
    "yes": "sim",
    "Zoom in": "Aproximar",
    "Zoom level for automatic zooms": "Nível de aproximação para aproximações automáticas",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Aproximar ao tamanho da camada",
    "Zoom to the next": "Aproximar para o seguinte",
    "Zoom to the previous": "Aproximar para o anterior",
    "Zoom to this feature": "Aproximar a este elemento",
    "{area}&#8239;acres": "{area} hectares",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} erros ao importar: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} milhas",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Editar o nome e a legenda do mapa",
    "Map advanced properties": "Propriedades avançadas do mapa",
    "Edit map details": "Editar detalhes do mapa",
    "Back to browser": "Voltar ao navegador",
    "Toggle size": "Alternar tamanho",
    "Display the caption control": "Mostrar o controlo de legendas",
    "<empty value>": "<empty value>",
    "Min": "Mín",
    "Max": "Máx",
    "From": "De",
    "Until": "Até",
    "Edit in OpenStreetMap": "Editar no OpenStreetMap",
    "Back to layers": "Voltar às camadas",
    "Filters": "Filtros",
    "Comma separated list of properties to use when filtering features by text input": "Lista de propriedades separada por vírgulas a utilizar na filtragem de elementos por introdução de texto",
    "Search keys": "Pesquisar chaves",
    "Filter data": "Filtrar dados",
    "Search map features…": "Pesquisar elementos do mapa…",
    "Reset all": "Repor tudo",
    "Open browser": "Abrir navegador",
    "Open caption": "Abrir legenda",
    "Real-time collaboration": "Colaboração em tempo real",
    "Cannot parse data": "Não é possível analisar os dados",
    "Start typing...": "Começar a escrever...",
    "No result": "Nenhum resultado",
    "Data browser": "Navegador de dados",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Ao fornecer um URL, o uMap pode copiar os dados remotos numa camada ou adicionar esse URL como fonte remota da camada. Nesse caso, os dados serão sempre obtidos a partir desse URL e, por conseguinte, estarão atualizados, mas não será possível editá-los no uMap.",
    "Overpass supported expressions": "Expressões suportadas do Overpass",
    "key (eg. building)": "chave (por exemplo building)",
    "!key (eg. !name)": "!chave (por exemplo !name)",
    "key=value (eg. building=yes)": "chave=valor (por exemplo building=yes)",
    "key!=value (eg. building!=yes)": "chave!=valor (por exemplo building!=yes)",
    "key~value (eg. name~Grisy)": "chave~valor (por exemplo name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "chave=\"valor|valor2\" (por exemplo name=\"Lisboa|Berlim\")",
    "More info about Overpass syntax": "Mais informações sobre a sintaxe do Overpass",
    "For more complex needs, see": "Para necessidades mais complexas, ver",
    "Choose data": "Selecionar dados",
    "Choose the format": "Selecionar o formato",
    "Choose the layer": "Selecionar a camada",
    "Layer name": "Nome da camada",
    "Choose import mode": "Selecionar o modo de importação",
    "Copy into the layer": "Copiar para a camada",
    "Link to the layer as remote data": "Hiperligação para camada como dados remotos",
    "Condition": "Condição",
    "key=value or key!=value": "chave=valor ou chave!=valor",
    "Are you sure you want to delete this rule?": "Tem a certeza de que pretende eliminar esta regra?",
    "empty rule": "Regra vazia",
    "Conditional style rules": "Regras de estilo condicionais",
    "Add rule": "Adicionar regra",
    "Browser: data": "Navegador: dados",
    "Browser: layers": "Navegador: camadas",
    "Browser: filters": "Navegador: filtros",
    "Enable real-time collaboration": "Ativar a colaboração em tempo real",
    "✅ Copied!": "✅ Copiado!",
    "Choose a dataset": "Escolher um conjunto de dados",
    "Choose this dataset": "Escolher este conjunto de dados",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: dados temáticos do OpenStreetMap",
    "Choose a theme": "Escolher um tema",
    "Choose this data": "Escolher estes dados",
    "Search admin boundary": "Pesquisar limites administrativos",
    "Please choose a theme and a boundary first.": "Escolha primeiro um tema e um limite.",
    "Expression": "Expressão",
    "Geometry mode": "Modo de geometria",
    "Only geometry centers": "Apenas centros de geometria",
    "Search area": "Pesquisar área",
    "Type area name, or let empty to load data in current map view": "Introduzir o nome da área ou deixar em branco para carregar os dados na vista de mapa atual",
    "Data successfully imported!": "Dados importados com sucesso!",
    "Clear data": "Limpar dados",
    "Remove layers": "Remover camadas",
    "Categorized": "Categorizado",
    "Alphabetical": "Por ordem alfabética",
    "Category property": "Categoria da propriedade",
    "Color palette": "Paleta de cores",
    "Categories": "Categorias",
    "Comma separated list of categories.": "Lista de categorias separada por vírgulas.",
    "Categories mode": "Modo de categorias",
    "Name “{name}” should not contain a dot.": "O nome “{name}” não deve conter um ponto.",
    "This name already exists: “{name}”": "Este nome já existe: “{name}”",
    "Delete selected rows": "Eliminar as linhas selecionadas",
    "Found {count} rows. Are you sure you want to delete all?": "Foram encontradas {count} linhas. Tem a certeza de que pretende apagar todas?",
    "Expression is empty": "A expressão está vazia",
    "OK": "OK",
    "Cancel": "Cancelar",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.",
    "More help resources": "More help resources",
    "This map is a template": "This map is a template",
    "Add text along path": "Add text along path",
    "Text color": "Text color",
    "Text offset": "Text offset",
    "Text position": "Text position",
    "start": "start",
    "center": "center",
    "end": "end",
    "Text repeat": "Text repeat",
    "Text rotate": "Text rotate",
    "Text size": "Text size",
    "Load map template": "Load map template",
    "My templates": "My templates",
    "From staff": "From staff",
    "From community": "From community",
    "You must select a template.": "You must select a template.",
    "Line decoration": "Line decoration",
    "Reuse this template": "Reuse this template",
    "Create a new map using this template": "Create a new map using this template",
    "Save template": "Save template",
    "Load template": "Load template",
    "Loading a template will apply predefined styles and settings to your map": "Loading a template will apply predefined styles and settings to your map",
    "Load template with data": "Load template with data",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.",
    "There is no public template yet.": "There is no public template yet.",
    "Explore": "Explore",
    "Import data from public open data portals": "Import data from public open data portals",
    "Choose a portal": "Choose a portal",
    "Limit results to current map view": "Limit results to current map view",
    "Please choose an instance first.": "Please choose an instance first.",
    "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.": "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.",
    "Add a new field": "Add a new field",
    "Cannot process MultiPoint": "Cannot process MultiPoint",
    "Manage Fields": "Manage Fields",
    "Delete this field": "Delete this field",
    "Double click to edit the name": "Double click to edit the name",
    "Print map": "Print map",
    "Choose a format": "Choose a format",
    "Scale map": "Scale map",
    "portrait": "portrait",
    "landscape": "landscape",
    "Print": "Print",
    "Preparing the print…": "Preparing the print…",
    "Large Circle": "Large Circle",
    "Icon size": "Icon size",
    "Will only affect raw and large circle icons.": "Will only affect raw and large circle icons.",
    "Route": "Route",
    "Display the print control": "Display the print control",
    "Compute isochrone from here": "Compute isochrone from here",
    "Route settings": "Route settings",
    "Transform to regular line": "Transform to regular line",
    "Transform to route": "Transform to route",
    "Restore route": "Restore route",
    "Profile": "Profile",
    "Compute elevations": "Compute elevations",
    "Route preference": "Route preference",
    "Compute route": "Compute route",
    "Walking": "Walking",
    "Hiking": "Hiking",
    "By car": "By car",
    "Cycling": "Cycling",
    "Wheelchair": "Wheelchair",
    "Recommended": "Recommended",
    "Fastest": "Fastest",
    "Shortest": "Shortest",
    "Max time (in minutes)": "Max time (in minutes)",
    "Number of lines": "Number of lines",
    "Distance:": "Distance:",
    "Gain:": "Gain:",
    "Loss:": "Loss:",
    "Altitude:": "Altitude:",
    "Right-click to edit": "Right-click to edit",
    "Draw along routes": "Draw along routes",
    "Skipping invalid geometry": "Skipping invalid geometry",
    "Add filter": "Add filter",
    "Min/Max": "Min/Max",
    "Multiple choices": "Multiple choices",
    "Exclusive choice": "Exclusive choice",
    "Yes/No": "Yes/No",
    "Add a field prior to create a filter.": "Add a field prior to create a filter.",
    "Edit this filter": "Edit this filter",
    "Remove this filter": "Remove this filter",
    "Apply filter to": "Apply filter to",
    "Filter on": "Filter on",
    "Human readable name of the filter": "Human readable name of the filter",
    "Widget for the filter": "Widget for the filter",
    "Edit filter": "Edit filter",
    "Edit this field": "Edit this field",
    "all layers": "all layers",
    "single layer": "single layer",
    "unset": "unset",
    "Filters will be displayed in the data browser to ease data selection.": "Filters will be displayed in the data browser to ease data selection.",
    "[key=\"value\"][key2=\"value2\"] (eg. [boundary=\"educational\"][name=\"Académie de Lyon\"])": "[key=\"value\"][key2=\"value2\"] (eg. [boundary=\"educational\"][name=\"Académie de Lyon\"])",
    "Field Name": "Field Name",
    "Field Type": "Field Type",
    "Manage field": "Manage field",
    "Add filter for this field": "Add filter for this field",
    "Name cannot be empty.": "Name cannot be empty.",
    "Are you sure you want to delete this field on all the data?": "Are you sure you want to delete this field on all the data?",
    "Anonymous map": "Anonymous map",
    "Edit filter for this field": "Edit filter for this field",
    "Hey, you created a map without an account!": "Hey, you created a map without an account!",
    "This map is anonymous, do you want to attach it to your account?": "This map is anonymous, do you want to attach it to your account?",
    "The map has been upgraded to latest version, please save it.": "The map has been upgraded to latest version, please save it.",
    "Elevation has been added!": "Elevation has been added!",
    "Mapillary": "Mapillary",
    "Wikidata": "Wikidata",
    "Wikipedia contributors": "Wikipedia contributors",
    "See on Wikipedia": "See on Wikipedia",
    "Anonymous map: update who can see and edit it": "Anonymous map: update who can see and edit it",
    "Login": "Login",
    "Manage filters": "Manage filters",
    "Map (all layers)": "Map (all layers)",
    "Add a filter for this field": "Add a filter for this field",
    "Short text": "Short text",
    "Text": "Text",
    "Number": "Number",
    "Date": "Date",
    "Date and time": "Date and time",
    "List of values": "List of values",
    "Yes / No": "Yes / No",
    "Select field to compute intensity": "Select field to compute intensity",
    "Optional intensity field to compute heatmap": "Optional intensity field to compute heatmap",
    "All layers": "All layers",
    "Comma separated list of values": "Comma separated list of values",
    "Share": "Share",
    "Customized link": "Customized link",
    "Iframe": "Iframe"
}
L.registerLocale("pt_PT", locale)
L.setLocale("pt_PT")
