const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(lunghezza: {measure})",
    "# one hash for main heading": "# un cancelleto per l'intestazione principale",
    "## two hashes for second heading": "## due cancelletti per le intestazioni di secondo livello",
    "### three hashes for third heading": "### tre cancelletti per intestazione di terzo livello",
    "**double star for bold**": "**due asterischi per il testo marcato**",
    "*single star for italic*": "*un solo asterisco per il corsivo*",
    "--- for a horizontal rule": "--- per una linea orizzontale",
    "1 day": "1 giorno",
    "1 hour": "1 ora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista di numeri separati da virgola che definisce lo schema del tratto e del trattino. Es.: \"5, 10, 15\".",
    "About": "Informazioni",
    "Action not allowed :(": "Azione non permessa :(",
    "Activate slideshow mode": "Attiva la modalità presentazione",
    "Add a layer": "Aggiungi un layer",
    "Add a line to the current multi": "Aggiungi una linea a quelle correnti",
    "Add a polygon to the current multi": "Aggiungi un poligono a quell correnti",
    "Add image URL": "Aggiungi URL immagine",
    "Advanced actions": "Azioni avanzate",
    "Advanced properties": "Proprietà avanzate",
    "All data and settings of the map": "Tutti i dati e le impostazioni della mappa",
    "All properties are imported.": "Tutte le proprietà sono state importate.",
    "Allow interactions": "Permetti interazioni",
    "Allow scroll wheel zoom?": "Abilitare la rotellina del mouse per lo zoom?",
    "always": "sempre",
    "Animated transitions": "Transizioni animate",
    "Are you sure you want to clone this map and all its datalayers?": "Confermi di duplicare questa mappa e tutti i suoi livelli?",
    "Are you sure you want to delete this map?": "Si è certi di voler eliminare questa mappa?",
    "Are you sure you want to restore this version?": "Si vuole veramente ripristinare questa versione?",
    "Attach the map to my account": "Collega la mappa al mio account",
    "attribution": "attribuzione",
    "Auto": "Auto",
    "Automatic": "Automatico",
    "Autostart when map is loaded": "Partenza automatica una volta che la mappa è stata caricata",
    "Back to preview": "Torna all’anteprima",
    "Background overlay url": "URL sfondo in sovrapposizione",
    "Ball": "Palla",
    "Bring feature to center": "Sposta l’oggetto al centro",
    "Browse data": "Visualizza i dati",
    "by": "di",
    "Cache proxied request": "Usa la cache per le richieste proxy",
    "Caption": "Didascalia",
    "Center map on your location": "Centra la mappa sulla tua posizione",
    "Change tilelayers": "Cambia i livelli di sfondo",
    "Change": "Cambia",
    "Choose the data format": "Scegli il formato dati",
    "Choropleth breakpoints": "Punti di interruzione coropletici",
    "Choropleth classes": "Classi coropletiche",
    "Choropleth color palette": "Palett dei colori coropletici",
    "Choropleth mode": "Modo coropletico",
    "Choropleth property value": "Valore della proprietà coropletica",
    "Choropleth": "Coropletica",
    "Circle": "Cerchio",
    "clear": "pulisci",
    "Click last point to finish shape": "Click su ultimo punto per completare la geometria",
    "Click to add a marker": "Clicca per aggiungere un marcatore",
    "Click to continue drawing": "Clic per continuare a disegnare",
    "Click to start drawing a line": "Clic per iniziare a disegnare una linea",
    "Click to start drawing a polygon": "Clicca per iniziare a disegnare un poligono",
    "Clone of {name}": "Clone di {name}",
    "Clone this feature": "Duplica questo oggetto",
    "Clone this map": "Duplica questa mappa",
    "Clone": "Clona",
    "Close": "Chiudi",
    "Clustered": "Raggruppata",
    "Clustering radius": "Raggio del raggruppamento",
    "collapsed": "contratto",
    "color": "colore",
    "Comma separated list of numbers, including min and max values.": "Lista dei numeri separati da virgola, che includono i valori minimi e massimi",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Elenco di proprietà separate da virgole da utilizzare per l'ordinamento degli oggetti. Per invertire l'ordinamento, inserire prima un segno meno (-). Per esempio. miocampo-altrocampo.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the beginning of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the beginning of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Complimenti, la tua mappa è stata creata!!!",
    "Continue line": "Linea continua",
    "Coordinates": "Coordinate",
    "copy": "copia",
    "Credits": "Ringraziamenti",
    "Current map view": "Vista della mappa corrente",
    "Current view instead of default map view?": "Vista attuale invece che quella della mappa preimpostata?",
    "Custom background": "Sfondo personalizzato",
    "Custom overlay": "Sovrapposizione personalizzata",
    "dash array": "tratteggio",
    "Data is browsable": "I dati sono consultabili",
    "Datalayers": "Strati di dati",
    "Default interaction options": "Opzioni di interazione predefinite",
    "Default properties": "Proprietà preimpostate",
    "Default shape properties": "Proprietà predefinite della forma",
    "Default view": "Vista predefinita",
    "Default zoom level": "Livello di zoom predefinito",
    "Default": "Predefinito",
    "Default: name": "Predefinito: nome",
    "Define link to open in a new window on polygon click.": "Definisci un link d'aprire in una nuova finestra al clic sul poligono.",
    "define": "definisci",
    "Delay between two transitions when in play mode": "Ritardo tra le due transizioni in modalità di riproduzione",
    "Delete layer": "Elimina layer",
    "Delete this feature": "Cancella questo oggetto",
    "Delete this shape": "Cancella questa forma",
    "Delete this vertex (Alt+Click)": "Elimina questo vertice (Alt+Clic)",
    "Delete": "Cancella",
    "description": "descrizione",
    "Directions from here": "Indicazioni stradali da qui",
    "Display label": "Mostra etichetta",
    "Display measure": "Calcola le distanze",
    "display name": "visualizza il nome",
    "Display on load": "Mostra al caricamento",
    "Display the control to open OpenStreetMap editor": "Mostra il controllo per aprire l'editor di OpenStreetMap",
    "Display the embed control": "Visualizza il controllo per l'incorporamento",
    "Display the fullscreen control": "Visualizza il controllo di schermo intero",
    "Display the locate control": "Visualizza il controllo di localizzazione",
    "Display the measure control": "Visualizza il controllo di misurazione",
    "Display the search control": "Visualizza il controllo di ricerca",
    "Display the tile layers control": "Visualizza il controllo del livello delle tile",
    "Display the zoom control": "Visualizza il controllo di zoom",
    "Do you want to display a caption bar?": "Visualizzare una didascalia?",
    "Do you want to display a minimap?": "Visualizzare una mappa panoramica?",
    "Do you want to display a panel on load?": "Visualizza un panello al caricamento?",
    "Do you want to display caption menus?": "Si vuole visualizzare le etichette dei menu? ",
    "Do you want to display popup footer?": "Visualizzare la finestra di popup a piè pagina?",
    "Do you want to display the scale control?": "Visualizzare la scala?",
    "Do you want to display the «more» control?": "Vuoi visualizzare il controllo \"altro\"?",
    "Download": "Download",
    "Drag to reorder": "Trascina per riordinare",
    "Draw a marker": "Aggiungi un marcatore",
    "Draw a polygon": "Disegna un poligono",
    "Draw a polyline": "Disegna una polilinea",
    "Drawing": "Disegno",
    "Drop": "Goccia",
    "Dynamic properties": "Proprietà dinamiche",
    "Dynamic": "Dinamico",
    "Edit feature's layer": "Modifica gli oggetti del layer",
    "Edit properties in a table": "Modifica le proprietà in una tabella",
    "Edit the title of the map": "Modifica il titolo della mappa",
    "Edit this feature": "Modifica quest'oggetto",
    "Edit": "Modifica",
    "Embed and link options": "Opzioni di inclusione e collegamento",
    "Emoji & Character": "Emoji & caratteri",
    "Empty": "Vuoto",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Errore nell'URL della sovrapposizione",
    "Error in the tilelayer URL": "Errore nell'URL nel servizio di tile",
    "Exit Fullscreen": "Esci da Schermo intero",
    "expanded": "espanso",
    "Extract shape to separate feature": "Dividi la geometria in oggetti separati",
    "Feature identifier key": "Campo di identificativo dell'oggetto",
    "Feature properties": "Proprietà dell'oggetto",
    "Fetch data each time map view changes.": "Recupera i dati ad ogni cambio della visualizzazione della mappa.",
    "fill color": "colore di riempimento",
    "fill opacity": "opacità riempimento",
    "fill": "riempimento",
    "Fit all data": "Adatta tutti i dati",
    "Format": "Formato",
    "From zoom": "Dallo zoom",
    "full backup": "backup completo",
    "GeoRSS (only link)": "GeoRSS (solo il link)",
    "GeoRSS (title + image)": "GeoRSS (titolo + immagine)",
    "Go to \"{coords}\"": "Vai a “{coords}”",
    "Go to the homepage": "Vai all’homepage",
    "Go to «{feature}»": "Vai a «{feature}»",
    "Heatmap radius": "Raggio mappa di densità",
    "Heatmap": "Mappa di densità (heatmap)",
    "height": "altezza",
    "Help": "Aiuto",
    "hidden": "nascosto",
    "Hide controls": "Nascondi controlli",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Quanto vuoi semplificare la polilinea per ogni zoom (più = maggiori performance a aspetto più semplificato, meno = maggior dettaglio)",
    "icon opacity": "opacità dell'incona",
    "Icon shape": "Forma dell'icona",
    "Icon symbol": "Simbolo dell'icona",
    "If false, the polygon or line will act as a part of the underlying map.": "Se falso, il poligono o la linea si comporterà come parte della mappa sottostante.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe con altezza (in px) personalizzata: {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe con altezza e larghezza personalizzata (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Immagine con larghezza personalizzata (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Immagine: {{https://image.url.com}}",
    "Import data": "Importa dati",
    "Import in a new layer": "Importa in un nuovo layer",
    "Imports all umap data, including layers and settings.": "importa tutti i dati di umap compresi layer e le impostazioni",
    "Include full screen link?": "inserire link per la vista a schemo intero?",
    "Inherit": "Eredita",
    "inherit": "eredita",
    "Interaction options": "Opzioni di interazione",
    "Invalid latitude or longitude": "Latitudine o longitudine non corrette",
    "Invalid umap data in {filename}": "dati umap non validi nel file {filename}",
    "Invalid umap data": "dati di umap non validi",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Mantieni i layer attualmente visibili",
    "kilometers": "chilometri",
    "km": "km",
    "Label direction": "Direzione dell'etichetta",
    "Label key": "Campo etichetta",
    "Labels are clickable": "Etichette cliccabili",
    "Latest feature": "Ultimo oggetto",
    "Latitude": "Latitudine",
    "Layer properties": "Proprietà del layer",
    "Layer": "Layer",
    "Licence": "Licenza",
    "licence": "licenza",
    "Limit bounds": "Limiti di confine",
    "Link to view the map": "Collega per vedere la mappa",
    "Link to…": "Link a…",
    "Link with text: [[https://example.com|text of the link]]": "Collegamento con testo: [[https://esempio.it|testo del collegamento]]",
    "Long credits": "Ringraziamenti estesi",
    "Longitude": "Longitudine",
    "Manage layers": "Gestisci layer",
    "Manual": "Manuale",
    "Map background credits": "Riconoscimenti per la mappa di sfondo",
    "Map has been attached to your account": "La mappa è stata associata al tuo account",
    "Map has been saved!": "La mappa è stata salvata",
    "Map has been starred": "La mappa è stata contrassegnata come speciale",
    "Map has been unstarred": "La mappa è stata rimossa dalle speciali",
    "Map user content has been published under licence": "I contenuti della mappa sono rilasciati secondo la licenza",
    "Map's editors": "Contributori alla mappa",
    "Map's owner": "Proprietario della mappa",
    "max East": "max Est",
    "max North": "max Nord",
    "max South": "max Sud",
    "max West": "max Ovest",
    "max zoom": "zoom massimo",
    "Measure distances": "Misura le distanze",
    "Merge lines": "Unisci linee",
    "mi": "mi",
    "miles": "miglia",
    "min zoom": "zoom minimo",
    "More controls": "Maggiori controlli",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Deve avere un valore CSS valido (es.: DarkBlue o #123456)",
    "name": "nome",
    "nautical miles": "miglia nautiche",
    "never": "mai",
    "new window": "nuova finestra",
    "next": "prossimo",
    "NM": "NM",
    "No cache": "Nessuna cache",
    "No licence has been set": "Non è ancora stata impostata una licenza",
    "No results": "Nessun risultato",
    "no": "non",
    "None": "Nulla",
    "Number of desired classes (default 5)": "Numero di classi desiderate (default 5)",
    "On the bottom": "In basso",
    "On the left": "A sinistra",
    "On the right": "A destra",
    "On the top": "In alto",
    "Only visible layers' data": "Solo i dati dei livelli visibili",
    "opacity": "opacità",
    "Opacity": "Opacità",
    "Open current feature on load": "Apri l'oggetto attuale al caricamento",
    "Open link in…": "Apri link in…",
    "Open share & download panel": "Apri pannello di condivisione & scarico",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Apri quest'area della mappa nell'editor in modo da fornire dati più accurati in OpenStreeetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional. Same as color if not set.": "Opzionale. Stesso colore se non assegnato.",
    "Optional.": "Opzionale.",
    "Override clustering radius (default 80)": "Sovrascrivi raggio di raggruppamento (predefinito 80)",
    "Override heatmap radius (default 25)": "Sovrascrivi raggio mappa di intensità (predefinito 25)",
    "parent window": "finestra di origine",
    "Paste your data here": "Incolla i tuoi dati qui",
    "Permalink": "Link permanente",
    "Permanent credits background": "Sfondo ringraziamenti permanenti",
    "Permanent credits": "Ringraziamenti permanenti",
    "Please be sure the licence is compliant with your use.": "Si prega di verificare che la licenza è compatibile con quella in uso.",
    "Please choose a format": "Scegliere un formato",
    "Please save the map first": "Per favore prima salva la mappa",
    "Popup (large)": "Popup (grande)",
    "Popup content style": "Stile del contenuto del Popup",
    "Popup content template": "Modello del contenuto del popup",
    "Popup shape": "Forma del Popup",
    "Popup": "Popup",
    "Powered by uMap": "Alimentato da uMap",
    "previous": "precedente",
    "Problem in the response": "Problema nella risposta",
    "Properties imported:": "Proprietà importate:",
    "Provide an URL here": "Aggiungi una URL qui",
    "Proxy request": "Richiesta proxy",
    "Quantiles": "Quantili",
    "Recent": "Recente",
    "Remote data": "Dati remoti",
    "Replace layer content": "Sostituisci il contenuto del layer",
    "Restore this version": "Ripristina questa versione",
    "Save current edits": "Salva le modifiche effettuate",
    "Save map": "Salva mappa",
    "Save": "Salva",
    "Saved center and zoom": "Centro e zoom salvati",
    "Search location": "Cerca un luogo",
    "Search": "Ricerca",
    "Secret edit link:": "Link segreto per editare:",
    "See full screen": "Visualizza a schermo intero",
    "See on OpenStreetMap": "Vedi su OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Impostalo su false per nascondere questo layer dalla presentazione, dal browser dati, dalla navigazione popup...",
    "settings": "impostazioni",
    "Shape properties": "Proprietà della geometria",
    "Share and download": "Condividi e scarica",
    "Short credits": "Mostra i ringraziamenti",
    "Short link": "Collegamento corto",
    "Show this layer in the caption": "Mostra questo livello nella didascalia",
    "Show/hide layer": "Mostra/nascondi layer",
    "Side panel": "Pannello laterale",
    "Simple link: [[https://example.com]]": "Collegamento semplice: [[https://esempio.it]]",
    "Simplify": "Semplifica",
    "Skipping unknown geometry.type: {type}": "Salta le geometrie sconosciute di tipo: {type}",
    "Slideshow": "Presentazione",
    "Sort key": "Campo di ordinamento",
    "Split line": "Dividi linea",
    "Star this map": "Segna come mappa speciale",
    "Start a hole here": "Comincia un buco qui",
    "Start slideshow": "Avvia presentazione",
    "Stop editing": "Ferma la modifica",
    "Stop slideshow": "Ferma presentazione",
    "Street": "Strada",
    "stroke": "tratto",
    "Supported scheme": "Schema supportato",
    "Supported variables that will be dynamically replaced": "Variabili supportate che verranno cambiate dinamicamente",
    "Symbol": "Simbolo",
    "Table": "Tabella",
    "Text color for the cluster label": "Colore di testo per l'etichetta del raggruppamento",
    "Text formatting": "Formattazione testo",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Il nome della proprietà da usare come etichetta per l’elemento (ad es. \"nome\"). Puoi anche usare proprietà tra parentesi per specificarne più di una oppure combinarle con contenuti statici (ad es. “&lcub;nome&rcub; in &lcub;luogo&rcub;”)",
    "The name of the property to use as feature unique identifier.": "Nome della proprietà da utilizzare come identificatore univoco per ogni oggetto.",
    "The zoom and center have been modified.": "Lo zoom e il centro sono stati modificati",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Da utilizzare se il server remoto non permette l'accesso incrociato ai domini (lento)",
    "To zoom": "Allo zoom",
    "Toggle edit mode (⇧+Click)": "Attiva/disattiva la modalità di modifica (⇧+clic)",
    "Toggle edit mode": "Commuta modalità di modifica",
    "Transfer shape to edited feature": "Trasforma la geometria in un oggetto modificabile",
    "Transform to lines": "Trasforma in linee",
    "Transform to polygon": "Trasforma in poligono",
    "Type a place name or coordinates": "Inserisci il nome di un luogo o delle coordinate",
    "Type char or paste emoji": "Inserisci carattere o incolla emoji",
    "Type of layer": "Tipo di layer",
    "Unable to detect format of file {filename}": "Impossibile individuare il formato del file {filename}",
    "Untitled layer": "Layer senza nome",
    "Untitled map": "Mappa senza nome",
    "Update permissions and editors": "Cambia i permessi e i contributori",
    "Update permissions": "Aggiorna autorizzazioni",
    "Update who can see and edit the map": "Cambia chi può vedere e modificare la mappa",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Utilizza l'area in uso",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Specificando le proprietà dell'oggetto attraverso le parentesi graffe es. &#123;name&#125; queste saranno automaticamente sostituite con i valori corrispondenti",
    "User content credits": "Riconoscimenti ai contenuti utente",
    "User interface options": "Opzioni interfaccia utente",
    "User location": "Posizione dell'utente",
    "Verify remote URL": "Verifica URL remota",
    "Versions": "Versioni",
    "View Fullscreen": "Visualizza a schermo intero",
    "View": "Vedi",
    "Visibility: {status}": "Visibilità: {status}",
    "weight": "peso",
    "Where do we go from here?": "Da dove ci spostiamo da qui?",
    "Whether to display or not polygons paths.": "Indica se visualizzare o meno i lati dei poligoni.",
    "Whether to fill polygons with color.": "Indica se riempire i poligoni con il colore.",
    "Who can edit \"{layer}\"": "Chi può editare \"{layer}\"",
    "Who can edit": "Chi può modificare",
    "Who can view": "Chi può vedere",
    "width": "larghezza",
    "Will be displayed in the bottom right corner of the map": "Sarà visualizzato in un angolo in basso a destra sulla mappa",
    "Will be permanently visible in the bottom left corner of the map": "Sarà permanentemente visibile nell'angolo in basso a sinistra della mappa",
    "Will be visible in the caption of the map": "Sarà visibile nella didascalia della mappa",
    "yes": "sì",
    "Zoom in": "Ingrandisci",
    "Zoom level for automatic zooms": "Livelli di zoom per zoom automatici",
    "Zoom out": "Rimpicciolisci",
    "Zoom to layer extent": "Zoom alla larghezza massima del layer",
    "Zoom to the next": "Zoom sul prossimo",
    "Zoom to the previous": "Zoom sul precedente",
    "Zoom to this feature": "Zoom su questo oggetto",
    "{area}&#8239;acres": "{area} acri",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errori durante l'importazione: {message}",
    "{delay} seconds": "{delay} secondi",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miglia",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Modifica nome e descrizione della mappa",
    "Map advanced properties": "Proprietà avanzata della mappa",
    "Edit map details": "Modifica i dettagli della mappa",
    "Back to browser": "Torna all'elenco",
    "Toggle size": "Commuta dimensioni",
    "Display the caption control": "Visualizza il controllo delle didascalie",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "Da",
    "Until": "Fino a",
    "Edit in OpenStreetMap": "Modifica in OpenStreetMap",
    "Back to layers": "Torna ai livelli",
    "Filters": "Filtri",
    "Comma separated list of properties to use when filtering features by text input": "Lista di proprietà separate da virgola da utilizzare quando il filtro è impostato su testo ",
    "Search keys": "Chiavi di ricerca",
    "Filter data": "Filtra dati",
    "Search map features…": "Cerca elementi della mappa…",
    "Reset all": "Reimposta tutto",
    "Open browser": "Apri browser",
    "Open caption": "Apri didascalia",
    "Real-time collaboration": "Collaborazione in tempo reale",
    "Cannot parse data": "Impossibile analizzare i dati",
    "Start typing...": "Inizia a scrivere...",
    "No result": "Nessun risultato",
    "Data browser": "Browser dei dati",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Quando viene fornito un URL, uMap può copiare i dati remoti in un layer oppure aggiungere questo URL come fonte remota per il layer. In quel caso, i dati verranno sempre scaricati da quell’URL e quindi saranno aggiornati, ma non potranno essere modificati su uMap.",
    "Overpass supported expressions": "Espressioni di Overpass supportate",
    "key (eg. building)": "chiave (es. building)",
    "!key (eg. !name)": "!chiave (es. !name)",
    "key=value (eg. building=yes)": "chiave=valore (es. building=yes)",
    "key!=value (eg. building!=yes)": "chiave!=valore (es. building!=yes)",
    "key~value (eg. name~Grisy)": "chiave~valore (es. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "chiave=\"valore|valore2\" (es. name=\"Parigi|Berlino\")",
    "More info about Overpass syntax": "Più informazioni sulla sintassi di Overpass",
    "For more complex needs, see": "Per esigenze più complesse, consulta",
    "Choose data": "Seleziona i dati",
    "Choose the format": "Seleziona il formato",
    "Choose the layer": "Seleziona il livello",
    "Layer name": "Nome livello",
    "Choose import mode": "Seleziona la modalità di importazione",
    "Copy into the layer": "Copia nel livello",
    "Link to the layer as remote data": "Collega il livello come dati remoti",
    "Condition": "Condizione",
    "key=value or key!=value": "chiave=valore or chiave!=valore",
    "Are you sure you want to delete this rule?": "Si è certi di voler eliminare questa regola?",
    "empty rule": "regola vuota",
    "Conditional style rules": "Regole di stile condizionale",
    "Add rule": "Aggiungi regola",
    "Browser: data": "Browser: dati",
    "Browser: layers": "Browser: livelli",
    "Browser: filters": "Browser: filtri",
    "Enable real-time collaboration": "Abilita collaborazione in tempo reale",
    "✅ Copied!": "✅ Copiato!",
    "Choose a dataset": "Scegli un dataset",
    "Choose this dataset": "Scegli questo dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: dati tematici da OpenstreetMap",
    "Choose a theme": "Seleziona un tema",
    "Choose this data": "Seleziona questi dati",
    "Search admin boundary": "Cerca confini amministrativi",
    "Please choose a theme and a boundary first.": "Prima scegli un tema e un confine.",
    "Expression": "Espressione",
    "Geometry mode": "Modalità geometria",
    "Only geometry centers": "Solo i centri delle geometrie",
    "Search area": "Cerca area",
    "Type area name, or let empty to load data in current map view": "Scrivi il nome dell'area, o lascia vuoto per caricare i dati nella vista della mappa corrente",
    "Data successfully imported!": "Dati importati con successo!",
    "Clear data": "Rimuovi i dati",
    "Remove layers": "Rimuovi i livelli",
    "Categorized": "Categorizzato",
    "Alphabetical": "Alfabetico",
    "Category property": "Proprietà della categoria",
    "Color palette": "Palette di colori",
    "Categories": "Categorie",
    "Comma separated list of categories.": "Lista di categorie separate da virgola.",
    "Categories mode": "Modalità categorie",
    "Name “{name}” should not contain a dot.": "Il nome \"{name}\" non può contenere punti.",
    "This name already exists: “{name}”": "Questo nome esiste già: “{name}”",
    "Delete selected rows": "Rimuovi le righe selezionate",
    "Found {count} rows. Are you sure you want to delete all?": "{count} righe trovate. Si è certi di rimuoverle tutte?",
    "Expression is empty": "L'espressione è vuota",
    "OK": "OK",
    "Cancel": "Annulla",
    "Attach map to a team": "Collega la mappa ad un team",
    "Display the polygon inverted": "Mostra il poligono invertito",
    "Proportional circles": "Cerchi proporzionali",
    "Property name to compute circles": "Proprietà per cui calcolare i cerchi",
    "Min circle radius": "Raggio minimo del cerchio",
    "Max circle radius": "Raggio massimo del cerchio",
    "Display the open browser control": "Mostra il controllo apri browser",
    "Copy as GeoJSON": "Copia come GeoJSON",
    "Please zoom in to edit the geometry": "Ingrandisci per modificare la geometria",
    "New map": "Nuova mappa",
    "My maps": "Le mie mappe",
    "My teams": "I miei gruppi",
    "My profile": "Il mio profilo",
    "Type new owner's username": "Inserisci il nome utente del nuovo proprietario",
    "Type editor's username": "Inserisci il nome utente del contributore",
    "Map": "Mappa",
    "Manage collaborators": "Gestisci chi può collaborare",
    "show/hide all layers": "mostra/nascondi tutti i livelli",
    "zoom to data extent": "ingrandisci sull'area dei dati",
    "download visible data": "scarica i dati visibili",
    "Import helpers": "Importa guide",
    "Import helpers will fill the URL field for you.": "Importando le guide il campo URL verrà compilato automaticamente.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Salva bozza",
    "No data has been found for import": "Non sono stati trovati dati da importare",
    "Successfully imported {count} feature(s)": "Importato con successo {count} elemento/i",
    "Disconnected": "Scollegato",
    "You must be logged in": "Devi aver effettuato l’accesso",
    "on hover": "al passaggio del mouse",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Impossibile caricare i dati remoti per il layer “{layer}” con URL “{url}”",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Impossibile analizzare i dati remoti per il layer “{layer}” con URL “{url}”",
    "Import failed: invalid data": "Import fallito: dati non validi",
    "Anonymous": "Anonimo",
    "created at {date}": "creato il {date}",
    "modified at {date}": "modificato il {date}",
    "Default zoom": "Zoom predefinito",
    "Default latitude": "Latitudine predefinita",
    "Default longitude": "Longitudine predefinita",
    "Edit map default view": "Modifica la vista predefinita della mappa",
    "Use current center and zoom": "Usa centro e zoom attuali",
    "Layer permalink": "Permalink del layer",
    "Back to home": "Torna alla home",
    "Home logo": "Logo della home",
    "Add this geometry to my map": "Aggiungi questa geometria alla mia mappa",
    "Add this place to my map": "Aggiungi questo posto alla mia mappa",
    "Cancel last edit": "Annulla ultima modifica",
    "Redo last edit": "Rifai ultima modifica",
    "Links": "Collegamenti",
    "Images": "Immagini",
    "Iframes": "Iframe",
    "Tags": "Etichette",
    "Geocode": "Geocode",
    "Display the back to home icon": "Mostra l’icona per tornare alla home",
    "Do you want to display layer switcher in caption bar?": "Vuoi mostrare il commutatore dei layer nella didascalia?",
    "Simplify all geometries to points": "Semplifica tutte le geometrie con punti",
    "Back to list": "Torna alla lista",
    "Toggle rule": "Commuta regola",
    "Delete rule": "Cancella regola",
    "Cannot save layer, please try again in a few minutes.": "Impossibile salvare il layer, prova di nuovo tra qualche minuto.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.",
    "More help resources": "Altre risorse dell'help",
    "This map is a template": "Questa mappe è un template ",
    "Add text along path": "Add text along path",
    "Text color": "Colore del testo",
    "Text offset": "Text offset",
    "Text position": "Posizione del testo",
    "start": "inizio",
    "center": "centro",
    "end": "fine",
    "Text repeat": "Ripeti testo",
    "Text rotate": "Ruota testo",
    "Text size": "Dimensioni testo",
    "Load map template": "Load map template",
    "My templates": "My templates",
    "From staff": "Dallo staff",
    "From community": "Dalla community",
    "You must select a template.": "Devi selezionare un template",
    "Line decoration": "Line decoration",
    "Reuse this template": "Reuse this template",
    "Create a new map using this template": "Create a new map using this template",
    "Save template": "Save template",
    "Load template": "Load template",
    "Loading a template will apply predefined styles and settings to your map": "Loading a template will apply predefined styles and settings to your map",
    "Load template with data": "Load template with data",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.",
    "There is no public template yet.": "There is no public template yet.",
    "Explore": "Explore",
    "Import data from public open data portals": "Import data from public open data portals",
    "Choose a portal": "Choose a portal",
    "Limit results to current map view": "Limit results to current map view",
    "Please choose an instance first.": "Please choose an instance first.",
    "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.": "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.",
    "Add a new field": "Add a new field",
    "Cannot process MultiPoint": "Cannot process MultiPoint",
    "Manage Fields": "Manage Fields",
    "Delete this field": "Delete this field",
    "Double click to edit the name": "Double click to edit the name",
    "Print map": "Print map",
    "Choose a format": "Choose a format",
    "Scale map": "Scale map",
    "portrait": "portrait",
    "landscape": "landscape",
    "Print": "Print",
    "Preparing the print…": "Preparing the print…",
    "Large Circle": "Large Circle",
    "Icon size": "Icon size",
    "Will only affect raw and large circle icons.": "Will only affect raw and large circle icons.",
    "Route": "Route",
    "Display the print control": "Display the print control",
    "Compute isochrone from here": "Compute isochrone from here",
    "Route settings": "Route settings",
    "Transform to regular line": "Transform to regular line",
    "Transform to route": "Transform to route",
    "Restore route": "Restore route",
    "Profile": "Profile",
    "Compute elevations": "Compute elevations",
    "Route preference": "Route preference",
    "Compute route": "Compute route",
    "Walking": "Walking",
    "Hiking": "Hiking",
    "By car": "By car",
    "Cycling": "Cycling",
    "Wheelchair": "Wheelchair",
    "Recommended": "Recommended",
    "Fastest": "Fastest",
    "Shortest": "Shortest",
    "Max time (in minutes)": "Max time (in minutes)",
    "Number of lines": "Number of lines",
    "Distance:": "Distance:",
    "Gain:": "Gain:",
    "Loss:": "Loss:",
    "Altitude:": "Altitude:",
    "Right-click to edit": "Right-click to edit",
    "Draw along routes": "Draw along routes",
    "Skipping invalid geometry": "Skipping invalid geometry",
    "Add filter": "Add filter",
    "Min/Max": "Min/Max",
    "Multiple choices": "Multiple choices",
    "Exclusive choice": "Exclusive choice",
    "Yes/No": "Yes/No",
    "Add a field prior to create a filter.": "Add a field prior to create a filter.",
    "Edit this filter": "Edit this filter",
    "Remove this filter": "Remove this filter",
    "Apply filter to": "Apply filter to",
    "Filter on": "Filter on",
    "Human readable name of the filter": "Human readable name of the filter",
    "Widget for the filter": "Widget for the filter",
    "Edit filter": "Edit filter",
    "Edit this field": "Edit this field",
    "all layers": "all layers",
    "single layer": "single layer",
    "unset": "unset",
    "Filters will be displayed in the data browser to ease data selection.": "Filters will be displayed in the data browser to ease data selection.",
    "[key=\"value\"][key2=\"value2\"] (eg. [boundary=\"educational\"][name=\"Académie de Lyon\"])": "[key=\"value\"][key2=\"value2\"] (eg. [boundary=\"educational\"][name=\"Académie de Lyon\"])",
    "Field Name": "Field Name",
    "Field Type": "Field Type",
    "Manage field": "Manage field",
    "Add filter for this field": "Add filter for this field",
    "Name cannot be empty.": "Name cannot be empty.",
    "Are you sure you want to delete this field on all the data?": "Are you sure you want to delete this field on all the data?",
    "Anonymous map": "Anonymous map",
    "Edit filter for this field": "Edit filter for this field",
    "Hey, you created a map without an account!": "Hey, you created a map without an account!",
    "This map is anonymous, do you want to attach it to your account?": "This map is anonymous, do you want to attach it to your account?",
    "The map has been upgraded to latest version, please save it.": "The map has been upgraded to latest version, please save it.",
    "Elevation has been added!": "Elevation has been added!",
    "Mapillary": "Mapillary",
    "Wikidata": "Wikidata",
    "Wikipedia contributors": "Wikipedia contributors",
    "See on Wikipedia": "See on Wikipedia",
    "Anonymous map: update who can see and edit it": "Anonymous map: update who can see and edit it",
    "Login": "Login",
    "Manage filters": "Manage filters",
    "Map (all layers)": "Map (all layers)",
    "Add a filter for this field": "Add a filter for this field",
    "Short text": "Short text",
    "Text": "Text",
    "Number": "Number",
    "Date": "Date",
    "Date and time": "Date and time",
    "List of values": "List of values",
    "Yes / No": "Yes / No",
    "Select field to compute intensity": "Select field to compute intensity",
    "Optional intensity field to compute heatmap": "Optional intensity field to compute heatmap",
    "All layers": "All layers",
    "Comma separated list of values": "Comma separated list of values",
    "Share": "Share",
    "Customized link": "Customized link",
    "Iframe": "Iframe",
    "№": "№"
}
L.registerLocale("it", locale)
L.setLocale("it")
